version 10.0 
log using "C:\Documents and Settings\Matthew Golder\My Documents\publications\ajps2\final_version\replication\results_manytomany.log", replace

#delimit ;

*     ****************************************************************  *;
*     ***************************************************************** *;
*       File-Name:      results_manytomany.do                           *;
*       Date:           February 10, 2010                               *;
*       Author:         MG                                              *;
*       Purpose:        Replication results for many-to-many congruence *;
*                       for AJPS 2010 article.                          *;
*       Input File:     final.dta                                       *;
*       Output File:    results_manytomany.log                          *;
*       Data Output:    none                                            *;
*       Previous file:  final.dta                                       *;
*       Machine:        office                                          *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 80m;

use "C:\Documents and Settings\Matthew Golder\My Documents\publications\ajps2\final_version\replication\final.dta", clear;

set more off;

desc;

sum;

*     ****************************************************************  *;
*       Results for Table 3.                                            *;
*     ****************************************************************  *;

ttest congruence40_many_cdf, by(majoritarian);

*     ****************************************************************  *;
*       Robustness checks for Table 3. Results do not depend on whether *;
*       we use all citizens or just the top 40% to estimate party       *;
*       positions.                                                      *;
*     ****************************************************************  *;

ttest congruence_many_cdf, by(majoritarian);

*     ****************************************************************  *;
*       Results for Table 4.                                            *;
*     ****************************************************************  *;

regress congruence40_many_cdf disproportionality, robust cluster(countrycode);

*     ****************************************************************  *;
*       Robustness checks for Table 4. Results do not depend on whether *;
*       we use robust and clustered standard errors or not.             *;
*     ****************************************************************  *;

regress congruence40_many_cdf disproportionality, robust;

regress congruence40_many_cdf disproportionality;

*     ****************************************************************  *;
*       Robustness checks for Table 4. Results do not depend            *;
*       substantively on whether we use Gallagher's measure of          *;
*       disproportionality or average district magnitude.               *;
*     ****************************************************************  *;

regress congruence40_many_cdf magnitude, robust cluster(countrycode);
regress congruence40_many_cdf magnitude, robust;
regress congruence40_many_cdf magnitude;

*     ****************************************************************  *;
*       Robustness checks for Table 4. How stable are the results given *;
*       the somewhat small sample size?  Let's use a jackknife procedure*;
*       to sequentially drop a different observation and see how the    *;
*       coefficient on disproportionality changes.                      *;
*     ****************************************************************  *;

regress congruence40_many_cdf disproportionality, vce(jackknife, mse);

*     ****************************************************************  *;
*       Coefficient remains positive and significant.                   *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Robustness checks for Table 4. How stable are the results given *;
*       the somewhat small sample size?  Let's use a bootstrap procedure*;
*       to check robustness and obtain corrected standard errors.       *;
*     ****************************************************************  *;

bootstrap, reps(400) seed(10101): regress congruence40_many_cdf disproportionality;

*     ****************************************************************  *;
*       Coefficient remains positive and significant.                   *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Robustness checks for Table 4. The results do not depend on the *;
*       inclusion of countries where the left-right dimensions is not   *;
*       necessarily meaningful.                                         *;
*     ****************************************************************  *;

regress congruence40_many_cdf disproportionality if countrycode~=84, robust cluster(countrycode);   
regress congruence40_many_cdf magnitude  if countrycode~=84, robust cluster(countrycode);   


regress congruence40_many_cdf disproportionality if countrycode~=98, robust cluster(countrycode);   
regress congruence_many_cdf magnitude  if countrycode~=98, robust cluster(countrycode);   

regress congruence40_many_cdf disproportionality if countrycode~=103, robust cluster(countrycode); 
regress congruence40_many_cdf magnitude  if countrycode~=103, robust cluster(countrycode);   


regress congruence40_many_cdf disproportionality if countrycode~=111, robust cluster(countrycode);   
regress congruence_many_cdf magnitude  if countrycode~=111, robust cluster(countrycode);   


regress congruence40_many_cdf disproportionality if countrycode~=119, robust cluster(countrycode);   
regress congruence40_many_cdf magnitude  if countrycode~=119, robust cluster(countrycode);   


regress congruence40_many_cdf disproportionality if countrycode~=155, robust cluster(countrycode);   
regress congruence40_many_cdf magnitude if countrycode~=155, robust cluster(countrycode);   


regress congruence40_many_cdf disproportionality if countrycode~=176, robust cluster(countrycode);   
regress congruence40_many_cdf magnitude  if countrycode~=176, robust cluster(countrycode);   


regress congruence40_many_cdf disproportionality  if countrycode~=84 & countrycode~=98 & countrycode~=103 & countrycode~=111 & countrycode~=119 & countrycode~=155 & countrycode~=176, robust cluster(countrycode);   
regress congruence40_many_cdf magnitude  if countrycode~=84 & countrycode~=98 & countrycode~=103 & countrycode~=111 & countrycode~=119 & countrycode~=155 & countrycode~=176, robust cluster(countrycode);   

*     ****************************************************************  *;
*       Coefficient remains positive and significant.                   *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Robustness checks for Table 4. Are any observations exerting    *;
*       a strong effect on the results?                                 *;
*     ****************************************************************  *;

regress congruence40_many_cdf disproportionality;

predict lev, leverage;

sort lev;
list country year lev in -10/l;

*     ****************************************************************  *;
*       A point with leverage greater than (2k+2)/n should be carefully *;
*       examined. Here k is the number of predictors and n is the       *;
*       number of observations. 6/37=0.162. There is only one           *;
*       observation - France 2002 = 0.33 with a leverage greater than   *;
*       0.146.                                                          *;
*     ****************************************************************  *;

regress congruence_many_cdf disproportionality if countrycode~=107, robust cluster(countrycode);
regress congruence40_many_cdf disproportionality if countrycode~=107, robust cluster(countrycode);

*     ****************************************************************  *;
*       Coefficient remains positive and significant if we use all      *;
*       voters to place the parties.  It remains positive and very close*;
*       to significance (two-tailed) if we use the top 40% to place     *;
*       parties.  It is significant if we use a one-tailed test.        *;
*     ****************************************************************  *;

exit;
